@@ -123,8 +123,7 @@ else {                          // user templates
 }
 
 // fetch user variable from session
-$USER = $App->getSession('USER');
-
+$USER  = $App->getSession('USER');
 $DEBUG = $App->getConfig('DEBUG');
 
 /**
@@ -181,6 +180,9 @@ if (file_exists($SP_FILE)) {
         $App->view = 'error';
     }
 }
+else {
+    $App->log("  CTRL does not exist: $SP_FILE",3,'SPAF2');
+}
 
 /* *** POST CTRL HOOK ***/
 if (file_exists($MODULE.'/post_ctrl.php')) {
@@ -194,7 +196,7 @@ if (file_exists($MODULE.'/post_ctrl.php')) {
  * controller will not checked for authorization.
  *
  */
-$App->log("VIEW[$ACCESS_LEVEL]) ".$App->view,2,'SPAF2');
+$App->log("VIEW[$ACCESS_LEVEL] $App->view",2,'SPAF2');
 // check if file exists or call default view file. The default view
 // will not checked for authorization.
 $SP_FILE = $MODULE.'/view/' . $App->view . '.php';
@@ -209,6 +211,10 @@ if (file_exists($SP_FILE)) {
         $App->view = 'error';
     }
 }
+else {
+    $App->log("  VIEW does not exist: $SP_FILE",3,'SPAF2');
+}
+
 
 /* *** POST VIEW HOOK ***/
 if (file_exists($MODULE.'/post_view.php')) {
@@ -238,7 +244,7 @@ $App->assign('VIEW',$App->view);
 if ($App->getParam('SKIN')) {
     $App->setSkin($App->getParam('SKIN'));
 }
-@
+
 $App->log("TPL[$ACCESS_LEVEL] $App->view",2,'SPAF2');
 $App->template = $App->view;
 // header and footer relative to template_root
