@@ -39,14 +39,24 @@ $sessionMailId = $App->getParam('id');
 
 $disposition = 'attachment';
 $show_inline = $App->getConfigList('ATTACHMENT_INLINE',array('application/pdf','image/png'));
-if (in_array($contentType,$show_inline)) {
+
+if (in_array($contentType,$show_inline)) {  // --> a_showEmail
     $disposition = 'inline';
 }
+else { // show inline if file suffix matches
+    $itype_list = $App->getConfiglist('ATTACHMENT_INLINE_SUFFIX',array('application/pdf','image/png'));
+    foreach ($itype_list as $itype) {
+    list($type,$isuffix) = explode('/',$itype);
+        if (preg_match("/\.$isuffix$/i", $filename)) {
+            $disposition = 'inline';
+            $contentType = $itype;
+        }
+    }
+}
 
 try {
     $filename = urlencode($filename);
     $attachmentData = $Backend->fetchAttachment($archive,$sessionMailId,$filename, $attachmentId);
-
     header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
     header("Pragma: public");
     header('Content-Type: '.$contentType);
