@@ -49,15 +49,18 @@ else {
 
 // check cookie settings
 if (ini_get('session.cookie_secure')) {
-    @$_SERVER['HTTPS'] || error_log('BENNO RUNTIME ERROR: plaintext request while secure cookies enabled');
+    @$_SERVER['HTTPS'] || @$_SERVER['HTTP_X_FORWARDED_PROTO'] || error_log('BENNO RUNTIME ERROR: plaintext request while secure cookies enabled');
 }
 
+$http_hostname = preg_replace('/:\d*/','',@$_SERVER['HTTP_HOST']);
+$http_hostname = urlencode($http_hostname);
+
 // set cookie path
 $currentCookieParams = session_get_cookie_params();
 session_set_cookie_params(
     $currentCookieParams["lifetime"],
     dirname($_SERVER['SCRIPT_NAME']),
-    $_SERVER["HTTP_HOST"],
+    $http_hostname,
     $currentCookieParams["secure"],
     $currentCookieParams["httponly"]
 );
