@@ -40,7 +40,6 @@ class Query
      * id
      */
     var $id;
-    var $archive;           // archive for search
     var $text;              // content or search term
     var $sender;
     var $recipient;
@@ -59,12 +58,11 @@ class Query
     /**
      * Query constructor
      */
-    function __construct($id,$archive='',$text='',$dateFrom='',$dateTo='',$sender='',$recipient='',$subject='',$headerName='',$headerValue='',$isAttachment=false,$isSpam=false,$type='Simple')
+    function __construct($id,$text='',$dateFrom='',$dateTo='',$sender='',$recipient='',$subject='',$headerName='',$headerValue='',$isAttachment=false,$isSpam=false,$type='Simple')
     {
         global $App;
 
         $this->id = $id;
-        $this->archive = $archive;
         $this->text = $text;          // content or search term
         $this->dateFrom = $dateFrom;
         $this->dateTo = $dateTo;
@@ -148,6 +146,61 @@ class Query
     }
 
 
+
+    /**
+     * returns url-safe string of serialized object
+     *
+     * @return string
+     *
+     */
+    function getUrlParameter()
+    {
+        $QueryObject = $this;
+        $jobject = json_encode($this);
+        $queryData = base64_encode(gzcompress($jobject));
+
+        return str_replace(array('+','/','='),array('-','_',''),$queryData);  // url safe encoding
+    }
+
+
+    /**
+     * returns url-safe string of serialized object
+     *
+     * @return string
+     *
+     */
+    static function getUrlObject($queryData)
+    {
+
+        $queryData64 = str_replace(array('-','_'),array('+','/'),$queryData);  // url safe decoding
+        $queryDataGz = base64_decode($queryData64);
+        $queryDataJs = gzuncompress($queryDataGz); 
+
+        $Jobject = json_decode($queryDataJs);
+
+        $QueryObject = new Query($Jobject->id);
+
+        $QueryObject->id = $Jobject->id;
+        $QueryObject->text = $Jobject->text;
+        $QueryObject->dateFrom = $Jobject->dateFrom;
+        $QueryObject->dateTo = $Jobject->dateTo;
+        $QueryObject->sender = $Jobject->sender;
+        $QueryObject->recipient = $Jobject->recipient;
+        $QueryObject->subject = $Jobject->subject;
+        $QueryObject->headerName = $Jobject->headerName;
+        $QueryObject->headerValue = $Jobject->headerValue;
+        $QueryObject->isAttachment = $Jobject->isAttachment;
+        $QueryObject->isSpam = $Jobject->isSpam;
+        $QueryObject->sort  = $Jobject->sort;
+        $QueryObject->type = $Jobject->type;
+        $QueryObject->spamQuery = $Jobject->spamQuery;
+ 
+        // TEST:  echo -n '<urlparamer>'|tr - +|tr _ /|base64 -d|zlib-flate -uncompress
+        return $QueryObject;
+    }
+
+
+
     /**
      * returns string for the simple search form
      *
@@ -252,9 +305,6 @@ class Query
             $query_string .= ' '.$this->spamQuery;
         }
 
-        $date_range   = $this->_dateRange($this->dateFrom,$this->dateTo);
-        $query_string .= ' AND ('.$date_range.')';
-
         return $query_string;
 
     }
@@ -305,7 +355,6 @@ class Query
             }
         }
 
-
         if ($this->subject !== '') {
             $subject_string = $this->_format_query($this->subject,'Subject');
             $query_string .= '('.$subject_string.')';
@@ -515,6 +564,28 @@ class Query
         return "Date:[$firstString%20TO%20$lastString]";
     }
 
+
+    /**
+     * compatiblity to old (< v2.10.3) stored queries -> skip archive
+     */
+    function __unserialize(array $data): void
+    {
+        $this->id           = $data['id'];
+        $this->text         = $data['text'];
+        $this->dateFrom     = $data['dateFrom'];
+        $this->dateTo       = $data['dateTo'];
+        $this->sender       = $data['sender'];
+        $this->recipient    = $data['recipient'];
+        $this->subject      = $data['subject'];
+        $this->headerName   = $data['headerName'];
+        $this->headerValue  = $data['headerValue'];
+        $this->isAttachment = $data['isAttachment'];
+        $this->isSpam       = $data['isSpam'];
+        $this->sort         = $data['sort'];
+        $this->type         = $data['type'];
+        $this->spamQuery    = $data['spamQuery'];
+    }
+
 }
 
 ?>
