@@ -115,7 +115,7 @@ class UserDA extends Persistence
         $this->password = $row['password'];
         $this->name = $row['name'];
         $this->role = $row['role'];
-        $this->_load_role_permissions();
+        $this->load_role_permissions();
 
         $this->_load_container();
 
@@ -218,7 +218,16 @@ class UserDA extends Persistence
             $errvalue = stream_get_contents($pipes[2]);
             fclose($pipes[2]);
             if ($errvalue) {
-                $App->log('Authentication script error: '.$errvalue,3,'User/loadSExternal');
+                $error_lines = '';
+                $loglevel = 3;
+                foreach (explode("\n", $errvalue) as $error_line) {
+                    if (preg_match('/FATAL/',$error_line)) {
+                        $loglevel = 0;
+                    }
+                    $error_lines .= $error_line.'|';
+                }
+                $error_lines = rtrim($error_lines, '|');
+                $App->log('Authentication script error: '.$error_lines,$loglevel,'User/loadSExternal');
             }
 
             $return_value = proc_close($process);
@@ -445,7 +454,7 @@ class UserDA extends Persistence
             throw new Exception('ERR_AUTH');
         }
 
-        $this->_load_role_permissions();
+        $this->load_role_permissions();
         return FALSE;
     }
 
@@ -502,7 +511,7 @@ class UserDA extends Persistence
     }
 
 
-    function _load_role_permissions()
+    function load_role_permissions()
     {
         global $App;
         $App->log('DEBUG Load role permissions.',4);
